timeintervaltools.fuse_tangent_or_overlapping_intervals
=======================================================

.. autofunction:: abjad.tools.timeintervaltools.fuse_tangent_or_overlapping_intervals.fuse_tangent_or_overlapping_intervals
